import { Component, ViewEncapsulation } from '@angular/core';
import { MatDialog } from '@angular/material/dialog';
import { CompComposeComponent } from './compose/comp-compose.component';
import { CustomerComposeComponent } from './compose/customer-compose.component';
import { DepositComposeComponent } from './compose/deposit-compose.component';
import { DepositHistoryComposeComponent } from './compose/deposit-history-compose.component';
import { NoticeComposeComponent } from './compose/notice-compose.component';
import { SignInComposeComponent } from './compose/sign-in-compose.component';
import { SignUpComposeComponent } from './compose/sign-up-compose.component';
import { WithdrawComposeComponent } from './compose/withdraw-compose.component';
import { WithdrawHistoryComposeComponent } from './compose/withdraw-history-compose.component';

export enum ComposeMenuType {
  signin = 'signin',
  signup = 'Signup',
  deposit = 'Deposit',
  withdraw = 'Withdraw',
  notice = 'Notice',
  comp = 'Comp',
  customer = 'Customer',
  depositHistory = 'DepositHistory',
  withdrawHistory = 'WithdrawHistory',
}

@Component({
  selector: 'main',
  templateUrl: './main.component.html',
  encapsulation: ViewEncapsulation.None,
})
export class MainComponent {
  composeMenuType = ComposeMenuType;

  components = [
    {
      id: 'ag(1)',
      name: '에볼루션',
      summary: 'Evolution',
      exampleSpecs: {
        prefix: 'autocomplete-',
      },
      additionalApiDocs: [
        {
          name: 'Testing',
          path: 'material-autocomplete-testing.html',
        },
      ],
    },
    {
      id: 'allbet',
      name: '프라그메틱',
      summary: 'PragmaticPlay.',
      exampleSpecs: {
        prefix: 'badge-',
      },
      additionalApiDocs: [
        {
          name: 'Testing',
          path: 'material-badge-testing.html',
        },
      ],
    },
    {
      id: 'elysium',
      name: '드림게이밍',
      summary: 'DreamGaming',
      exampleSpecs: {
        prefix: 'bottom-sheet-',
      },
      additionalApiDocs: [
        {
          name: 'Testing',
          path: 'material-bottom-sheet-testing.html',
        },
      ],
    },
    {
      id: 'elysium',
      name: '마이크로게이밍',
      summary: 'MicroGaming',
      exampleSpecs: {
        prefix: 'button-',
        exclude: ['button-toggle-'],
      },
      additionalApiDocs: [
        {
          name: 'Testing',
          path: 'material-button-testing.html',
        },
      ],
    },
    {
      id: 'evolution',
      name: '오리엔탈플러스',
      summary: 'OrientalPlus',
      exampleSpecs: {
        prefix: 'button-toggle-',
      },
      additionalApiDocs: [
        {
          name: 'Testing',
          path: 'material-button-toggle-testing.html',
        },
      ],
    },
    {
      id: 'ezugi',
      name: '아시안게이밍',
      summary: 'AsiaGaming',
      exampleSpecs: {
        prefix: 'card-',
      },
      additionalApiDocs: [
        {
          name: 'Testing',
          path: 'material-card-testing.html',
        },
      ],
    },
    {
      id: 'ezugi',
      name: 'CQ9LIVE',
      summary: 'CQ9LIVE',
      exampleSpecs: {
        prefix: 'checkbox-',
      },
      additionalApiDocs: [
        {
          name: 'Testing',
          path: 'material-checkbox-testing.html',
        },
      ],
    },
    {
      id: 'ezugi',
      name: '이주기',
      summary: 'Ezugi',
      exampleSpecs: {
        prefix: 'chips-',
      },
      additionalApiDocs: [
        {
          name: 'Testing',
          path: 'material-chips-testing.html',
        },
      ],
    },

    // {
    //   id: 'ezugi',
    //   name: '비보카지노',
    //   summary: 'VIVO',
    //   exampleSpecs: {
    //     prefix: 'core-',
    //   },
    //   additionalApiDocs: [
    //     {
    //       name: 'Testing',
    //       path: 'material-core-testing.html',
    //     },
    //   ],
    // },
  ];

  data = {
    schedule: {
      today: [
        {
          title: '계좌 등록 안내',
          time: '2022-06-08',
        },
        {
          title: '오토프로그램 이용 안냐',
          time: '2022-06-08',
        },
        {
          title: '입출금 규정 안내',
          time: '2022-06-08',
        },
        {
          title: '원피(가상계좌)사용 안내',
          time: '2022-06-08',
        },
        {
          title: '입금문의 안내(필독)',
          time: '2022-06-08',
        },
      ],
    },
  };
  /**
   * Constructor
   */
  constructor(private _matDialog: MatDialog) {}

  /**
   * Track by function for ngFor loops
   *
   * @param index
   * @param item
   */
  trackByFn(index: number, item: any): any {
    return item.id || index;
  }

  /**
   * @param composeMenuType
   */
  __onClickCompose(composeMenuType: ComposeMenuType): void {
    let selectType: any;

    switch (composeMenuType) {
      case ComposeMenuType.signin:
        selectType = SignInComposeComponent;
        break;
      case ComposeMenuType.signup:
        selectType = SignUpComposeComponent;
        break;
      case ComposeMenuType.deposit:
        selectType = DepositComposeComponent;
        break;
      case ComposeMenuType.withdraw:
        selectType = WithdrawComposeComponent;
        break;
      case ComposeMenuType.notice:
        selectType = NoticeComposeComponent;
        break;
      case ComposeMenuType.comp:
        selectType = CompComposeComponent;
        break;
      case ComposeMenuType.customer:
        selectType = CustomerComposeComponent;
        break;
      case ComposeMenuType.depositHistory:
        selectType = DepositHistoryComposeComponent;
        break;
      case ComposeMenuType.withdrawHistory:
        selectType = WithdrawHistoryComposeComponent;
        break;
    }

    const dialogRef = this._matDialog.open(selectType);

    dialogRef.afterClosed().subscribe((result) => {
      console.log('Compose dialog was closed!');
    });
  }
}
